from typing import List

STOYS_UI_VERSION: str = "0.2.0"

STOYS_LIB_MIN_JAVA_VERSION: str = "1.8"
STOYS_LIB_VERSION: str = "0.5.0-SNAPSHOT"
STOYS_LIB_GROUP_ID: str = "io.stoys"
STOYS_LIB_MODULES: List[str] = ["stoys-scala", "stoys-spark", "stoys-spark-du"]
STOYS_LIB_SCALA_COMPAT_VERSION: str = "2.12"
STOYS_LIB_CLASSIFIER: str = "spark-shaded"

STOYS_EMBEDDED_DEPENDENCIES_PACKAGE: str = "stoys.deps._embedded"
